/*
* Copyright (C) 2021, KylinSoft Co., Ltd.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3, or (at your option)
* any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, see <http://www.gnu.org/licenses/&gt;.
*
*/

#include "failedpagewidget.h"
#include <ukui-log4qt.h>

FailedPageWidget::FailedPageWidget(QWidget *parent) :
    QWidget(parent),
    m_failedPageIcon(new QLabel()),
    m_failedPageText(new QLabel()),
    m_failedPageButton(new QPushButton()),
    m_failedPageVLayout(new QVBoxLayout())
{
    setupGui();
    initConnect();
}

void FailedPageWidget::setupGui()
{
    m_failedPageIcon->setPixmap(QPixmap(":/default-connect-page/detect-failed.svg"));
    m_failedPageIcon->setFixedSize(FailedPageIconSize);

    m_failedPageText->setEnabled(false);
    m_failedPageText->setText(tr("Not detect scanners, please connect scanners firstly!"));

    m_failedPageButton->setMinimumSize(FailedPageButtonSize);
    m_failedPageButton->setText(tr("Connect"));
    m_failedPageButton->adjustSize();
    m_failedPageButton->setFocusPolicy(Qt::StrongFocus);
    m_failedPageButton->setFocus();
    m_failedPageButton->setDefault(true);

    m_failedPageButton->setStyleSheet("QPushButton{background-color:rgb(55,144,250);color:rgb(255,255,255);}");


    m_failedPageVLayout->setSpacing(0);
    m_failedPageVLayout->addStretch();
    m_failedPageVLayout->addWidget(m_failedPageIcon, 0,  Qt::AlignCenter);
    m_failedPageVLayout->addSpacing(13);
    m_failedPageVLayout->addWidget(m_failedPageText, 0,  Qt::AlignCenter);
    m_failedPageVLayout->addSpacing(29);
    m_failedPageVLayout->addWidget(m_failedPageButton, 0,  Qt::AlignCenter);
    m_failedPageVLayout->addStretch();
    m_failedPageVLayout->setContentsMargins(0, 0, 0, 0);

    setLayout(m_failedPageVLayout);

}

void FailedPageWidget::initConnect()
{
    connect(m_failedPageButton, &QPushButton::clicked, this, [=](){
        emit scanButtonClicked();
    });

    connect(g_user_signal, &GlobalUserSignal::fontSizeChangedSignal, this, &FailedPageWidget::fontSizeChanged);
}

void FailedPageWidget::fontSizeChanged(int fontSize)
{
    QFont font;
    font.setPointSize(fontSize);
    m_failedPageButton->setFont(font);

}

