/*
* Copyright (C) 2021, KylinSoft Co., Ltd.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3, or (at your option)
* any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, see <http://www.gnu.org/licenses/&gt;.
*
*/

#include "ocrobject.h"

OcrObject::OcrObject(QObject *parent) : QObject(parent)
{
    doOcr();

}

void OcrObject::doOcr()
{
    KyInfo() << "begin to run ocr thread !\n";
    tesseract::TessBaseAPI  *api = new tesseract::TessBaseAPI();

    if (api->Init(NULL, "chi_sim")) {
        KyInfo() << "Could not initialize tesseract.\n";
        g_sane_object->ocrOutputText = tr("Unable to read text");

        g_user_signal->toolbarOcrOperationFinished();
        return;
    }

    KyInfo() << "before pixRead.";
    Pix *image = pixRead(ScanningPicture);
    if (! image) {
        KyInfo() << "pixRead error!";
        g_sane_object->ocrOutputText = tr("Unable to read text");
        if (api)
            api->End();

        g_user_signal->toolbarOcrOperationFinished();

        return;
    }
    if (image) {
        KyInfo() << "before setImage.";
        api->SetImage(image);
        g_sane_object->ocrOutputText = api->GetUTF8Text();
    }

    KyInfo() << "before destroy image.";
    if (api) {
        api->End();
    }
    if (image) {
        pixDestroy(&image);
    }

    g_user_signal->toolbarOcrOperationFinished();

}
