/*
* Copyright (C) 2021, KylinSoft Co., Ltd.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3, or (at your option)
* any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, see <http://www.gnu.org/licenses/&gt;.
*
*/

#ifndef TOOLBARWIDGET_H
#define TOOLBARWIDGET_H

#include "globalsignal.h"
#include "svghandler.h"
#include "saneobject.h"

#include <ukui-log4qt.h>

#include <QWidget>
#include <QPushButton>
#include <QButtonGroup>
#include <QLabel>
#include <QFrame>
#include <QHBoxLayout>
#include <QPainter>
#include <QGraphicsDropShadowEffect>
#include <QFont>
#include <QPainter>
#include <QPaintEvent>
#include <QStyleOption>
#include <QColor>
#include <QIcon>
#include <QPixmap>

#define ToolBarWidgetColor QColor(249, 249, 249, 0.8*255)
#define ToolBarWidgetBlur 18
#define ToolBarWidgetFixedSize QSize(421, 36)
#define ToolBarWidgetButtonSize QSize(36, 36)
#define ToolBarWidgetFrameSize QSize(1, 16)
#define ToolBarWidgetZoomButtonSize QSize(20, 20)

class ToolBarWidget : public QWidget
{
    Q_OBJECT
public:
    explicit ToolBarWidget(QWidget *parent = nullptr);

    void setupGui();
    void initConnect();

    void themeChangedIconBlackSettings();
    void themeChangedIconWhiteSettings();

signals:

protected:
    void paintEvent(QPaintEvent *event) override;

    void keyPressEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
    void keyReleaseEvent(QKeyEvent *event) Q_DECL_OVERRIDE;


public slots:
    void themeChangedWhiteSlot();
    void themeChangedBlackSlot();

    void percentageChangedSlot();

    void beautyButtonClickedSlot();
    void rectifyButtonClickedSlot();
    void ocrButtonClickedSlot();
    void cropButtonClickedSlot();
    void rotateButtonClickedSlot();
    void mirrorButtonClickedSlot();
    void watermarkButtonClickedSlot();
    void zoomoutButtonClickedSlot();
    void zoominButtonClickedSlot();

private:

    QPushButton *m_beautyButton;
    QPushButton *m_rectifyButton;
    QPushButton *m_ocrButton;

    QFrame *m_leftFrame;

    QPushButton *m_cropButton;
    QPushButton *m_rotateButton;
    QPushButton *m_mirrorButton;
    QPushButton *m_watermarkButton;

    QFrame *m_rightFrame;

    QPushButton *m_zoomOutButton; // Make small
    QLabel *m_percentageLabel;
    QPushButton *m_zoomInButton; // Make large

    QHBoxLayout *m_mainHLayout;
};

#endif // TOOLBARWIDGET_H
